@@ -64,7 +64,7 @@ except NameError:
     unicode = str
 
 # Semi-standard module versioning.
-__version__ = '8.4'
+__version__ = '9.0'
 
 # Initialize a logger.
 logger = logging.getLogger(__name__)
@@ -571,9 +571,9 @@ class ExternalCommand(ControllableProcess):
      :attr:`capture_stderr`, :attr:`check`, :attr:`directory`,
      :attr:`encoding`, :attr:`environment`, :attr:`fakeroot`, :attr:`input`,
      :attr:`logger`, :attr:`merge_streams`, :attr:`shell`, :attr:`silent`,
-     :attr:`stdout_file`, :attr:`stderr_file`, :attr:`sudo` and
-     :attr:`virtual_environment` properties allow you to configure how the
-     external command will be run (before it is started).
+     :attr:`stdout_file`, :attr:`stderr_file`, :attr:`uid`, :attr:`user`,
+     :attr:`sudo` and :attr:`virtual_environment` properties allow you to
+     configure how the external command will be run (before it is started).
 
     **Computed properties**
      The :attr:`command`, :attr:`command_line`, :attr:`decoded_stderr`,
@@ -618,11 +618,15 @@ class ExternalCommand(ControllableProcess):
         :param command: Any positional arguments are converted to a list and
                         used to set :attr:`command`.
         :param options: Keyword arguments can be used to conveniently override
-                        the default values of :attr:`async`, :attr:`capture`,
-                        :attr:`check`, :attr:`directory`, :attr:`encoding`,
+                        the default values of :attr:`async`, :attr:`callback`,
+                        :attr:`capture`, :attr:`capture_stderr`, :attr:`check`,
+                        :attr:`directory`, :attr:`encoding`,
                         :attr:`environment`, :attr:`fakeroot`, :attr:`input`,
-                        :attr:`logger`, :attr:`silent` and :attr:`sudo`. Any
-                        other keyword argument will raise :exc:`TypeError` as
+                        :attr:`logger`, :attr:`merge_streams`, :attr:`shell`,
+                        :attr:`silent`, :attr:`stdout_file`,
+                        :attr:`stderr_file`, :attr:`uid`, :attr:`user`,
+                        :attr:`sudo` and :attr:`virtual_environment`.Any other
+                        keyword argument will raise :exc:`TypeError` as
                         usual.
 
         The external command is not started until you call :func:`start()` or
@@ -747,42 +751,41 @@ class ExternalCommand(ControllableProcess):
           shell command line and prefixed by the applicable ``source ...``
           command.
 
+        - If :attr:`uid` or :attr:`user` is set the `sudo -u`` command will be
+          prefixed to the command line generated here.
+
         - If :attr:`fakeroot` or :attr:`sudo` is set the respective command
-          name may be prefixed to the command line generated here.
+          name is prefixed to the command line generated here (``sudo`` is only
+          prefixed when the current process doesn't already have super user
+          privileges).
         """
         command_line = list(self.command)
-        shell = self.shell
+        # Apply the `shell' and/or `virtual_environment' options.
         if self.virtual_environment:
             # Prepare to execute the command inside a Python virtual environment.
             activate_script = os.path.join(self.virtual_environment, 'bin', 'activate')
-            if shell:
+            if self.shell:
                 shell_command = 'source %s && %s' % (quote(activate_script), command_line[0])
                 command_line = [DEFAULT_SHELL, '-c', shell_command] + command_line[1:]
             else:
                 shell_command = 'source %s && %s' % (quote(activate_script), quote(command_line))
                 command_line = [DEFAULT_SHELL, '-c', shell_command]
-            # Prevent the code further down from wrapping the command line in a second shell.
-            shell = False
-        if shell:
+        elif self.shell:
             # Prepare to execute a shell command.
             command_line = [DEFAULT_SHELL, '-c'] + command_line
+        # Run the command under `fakeroot' to fake super user privileges?
+        if self.fakeroot:
+            command_line = ['fakeroot'] + command_line
+        # Run the command under `sudo' to enable super user privileges? (only if necessary)
+        if self.sudo and not self.have_superuser_privileges:
+            command_line = ['sudo'] + command_line
+        # Apply the `uid' or `user' options.
         if self.uid is not None:
             # Run the command under a different user ID.
             command_line = ['sudo', '-u', '#%i' % self.uid] + command_line
         elif self.user is not None:
             # Run the command under a different username.
             command_line = ['sudo', '-u', self.user] + command_line
-        elif (self.fakeroot or self.sudo) and not self.have_superuser_privileges:
-            if self.sudo:
-                # Superuser privileges requested by caller.
-                command_line = ['sudo'] + command_line
-            elif self.fakeroot and which('fakeroot'):
-                # fakeroot requested by caller and available.
-                command_line = ['fakeroot'] + command_line
-            else:
-                # fakeroot requested by caller but not available.
-                # FIXME Not a very secure (nor Do What I Mean) default!
-                command_line = ['sudo'] + command_line
         return command_line
 
     @property
