@@ -1,7 +1,7 @@
 # Programmer friendly subprocess wrapper.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: November 8, 2015
+# Last Change: January 13, 2016
 # URL: https://executor.readthedocs.org
 
 """
@@ -31,6 +31,7 @@ from executor import (
     CommandNotFound,
     ExternalCommand,
     ExternalCommandFailed,
+    execute_prepared,
     quote,
 )
 from executor.concurrent import CommandPool
@@ -154,6 +155,23 @@ def foreach(hosts, *command, **options):
     return dict(pool.commands).values()
 
 
+def remote(ssh_alias, *command, **options):
+    """
+    Execute a remote command (similar to :func:`.execute()`).
+
+    :param ssh_alias: Used to set :attr:`RemoteCommand.ssh_alias`.
+    :param command: All positional arguments are passed to
+                    :func:`RemoteCommand.__init__()`.
+    :param options: All keyword arguments are passed to
+                    :func:`RemoteCommand.__init__()`.
+    :returns: Refer to :func:`.execute_prepared()`.
+    :raises: :exc:`RemoteCommandFailed` when the command exits with a
+             nonzero exit code (and :attr:`~.ExternalCommand.check` is
+             :data:`True`).
+    """
+    return execute_prepared(RemoteCommand(ssh_alias, *command, **options))
+
+
 class RemoteCommand(ExternalCommand):
 
     """:class:`RemoteCommand` objects use the SSH client program to execute remote commands."""
@@ -181,7 +199,8 @@ class RemoteCommand(ExternalCommand):
         self.ssh_alias = ssh_alias
         self.remote_directory = DEFAULT_WORKING_DIRECTORY
         # Initialize the super class.
-        super(RemoteCommand, self).__init__(*command, logger=logger, **options)
+        options.setdefault('logger', logger)
+        super(RemoteCommand, self).__init__(*command, **options)
 
     @mutable_property
     def batch_mode(self):
@@ -225,10 +244,8 @@ class RemoteCommand(ExternalCommand):
         ssh_command.extend(('-o', 'LogLevel=%s' % self.log_level))
         if self.strict_host_key_checking in ('yes', 'no', 'ask'):
             ssh_command.extend(('-o', 'StrictHostKeyChecking=%s' % self.strict_host_key_checking))
-        elif self.strict_host_key_checking:
-            ssh_command.extend(('-o', 'StrictHostKeyChecking=yes'))
         else:
-            ssh_command.extend(('-o', 'StrictHostKeyChecking=no'))
+            ssh_command.extend(('-o', 'StrictHostKeyChecking=%s' % ('yes' if self.strict_host_key_checking else 'no')))
         ssh_command.extend(('-o', 'UserKnownHostsFile=%s' % self.known_hosts_file))
         ssh_command.append(self.ssh_alias)
         remote_command = quote(super(RemoteCommand, self).command_line)
@@ -251,7 +268,7 @@ class RemoteCommand(ExternalCommand):
 
         Defaults to :data:`DEFAULT_CONNECT_TIMEOUT` so that non-interactive SSH
         connections created by :class:`RemoteCommand` don't hang indefinitely
-        when the remote system that doesn't respond (properly).
+        when the remote system doesn't respond properly.
         """
         return DEFAULT_CONNECT_TIMEOUT
 
